@@ -1,5 +1,6 @@
 // Import the highlighting theme
-const THEME: &[u8] = include_bytes!("../assets/theme.xml");
+const THEME: &[u8] = include_bytes!("../assets/compressed_theme");
+const SYNTAXES: &[u8] = include_bytes!("../assets/compressed_syntaxes");
 
 // All UI abtractions
 mod hui;
@@ -18,6 +19,7 @@ pub fn main() {
   // We start by handling command line input
   let args: Args = argh::from_env();
   
+  // Use the parsed input to configure UI and editor
   let path = args.path;
 
   // Create buffer and use command line input to init it
